var controllers = angular.module("famousControllers", []);

controllers.controller("dialogCtrl", ["$scope", "$action", "$correct", "$dialogView", "$dialogLang",
						function($scope, $action, $correct, $dialogView, $dialogLang){
	$scope.type = Constant.LIKE_TYPE;

	$scope.response = function(response){
		$dialogView.manageView($scope, response);
	}

	$scope.hideDialogBidLikes = function(){
		$dialogView.hideDialogBidLikes();
	}

	$scope.hidePrivateAcc = function(){
		$dialogView.hidePrivateAcc();
	}

	$scope.hideDeleteTask = function(){
		$dialogView.hideDeleteTask();
	}

	$scope.confirmDeleteTask = function(){
		$action.deleteTask($dialogView.deleteData.scope, $dialogView.deleteData.task);
	}
	
	$scope.bid = function(){
		$scope.link = Constant.HOME_PAGE + Constant.LIKES_LINK_IDENTIFIER + $scope.bidLikeId;

		$dialogView.setButAnim(true);
		var status = $correct.checkCorrect($scope.type, $scope.link, $scope.targetCountDialog);

		if(status.status == Constant.OK_STATUS){
			$action.bid($scope, new Bid($scope.link, $scope.targetCountDialog, $scope.type));
		}else{
			$dialogView.setButAnim(false);
			$dialogView.showToast(status.message);
		}
	}

	$scope.changePrice = function(){
		if($scope.targetCountDialog >= 0 && $scope.targetCountDialog != '')
			$dialogView.setPrice($scope, $scope.targetCountDialog * Constant.LIKE_PRICE, 1);
		else
			$dialogView.setPrice($scope, $scope.targetCountDialog * Constant.LIKE_PRICE, 2);
	}

	$dialogView.showInitLoading();
	$dialogView.initViewParams();
	
	$dialogLang.setLang($scope);
}]);

controllers.controller("loginCtrl", ["$scope", "$auth", "$loginView", "$loginLang", "$dialogView", "$way",
						function($scope, $auth, $loginView, $loginLang, $dialogView, $way){
	$way.step($scope, "/login");

	$scope.response = function(response){
		$loginView.manageView($scope, response);
		setTimeout(function(){
			$dialogView.hideLoading();
		}, 700);
	}

	$scope.auth = function(){
		$dialogView.showLoading();
		$auth.auth($scope, new AuthData($scope.login, $scope.password, $scope.authType, ""));
	}
	
	$loginView.initViewParams();

	$auth.preload($scope);

	$loginLang.setLang($scope);
}]);

controllers.controller("newsCtrl", ["$scope", "$rootScope", "$action", "$newsView", "$newsLang", "$dialogView", "$navView", "$way", "$heighter",
						function($scope, $rootScope, $action, $newsView, $newsLang, $dialogView, $navView, $way, $heighter){
	$rootScope.locationTitle = $dialogView.strings.newsTitle;
	$way.step($scope, "/news");

	$navView.setNavBut(Constant.NEWS_VIEW);

	$scope.response = function(response){
		$newsView.manageView($scope, response);
		setTimeout(function(){
			$newsView.show();
			$dialogView.hideLoading();
		}, 600);
	}
	
	$scope.completeFull = function(name, id, message, value){
		$action.complete(name, id, message, value, $scope);
	}
	
	$scope.news = function(){
		$dialogView.showLoading();
		$action.news($scope);
	}
	
	$scope.setHeight = function(){
		return $heighter.setHeight(Constant.NEWS_VIEW);
	}
	
	$scope.news();

	$newsView.initViewParams();
	$newsLang.setLang($scope);
}]);

controllers.controller("donateCtrl", ["$scope", "$rootScope", "$routeParams", "$donateView", "$store", "$donateLang", "$dialogView", "$navView", "$way", "$heighter",
						function($scope, $rootScope, $routeParams, $donateView, $store, $donateLang, $dialogView, $navView, $way, $heighter){
	$rootScope.locationTitle = $dialogView.strings.donateTitle;
	$way.step($scope, "/donate/diamonds");

	$navView.setNavBut(Constant.DONATE_VIEW);

	$scope.response = function(response){
		$donateView.setDonateContent($scope, $routeParams.id);
		$donateView.manageView($scope, response);
		$dialogView.hideLoading();
	}

	$scope.order = function(id){
		$store.order(id);
	}
	
	$scope.init = function(){
		$store.init($scope.response);
	}
	
	$scope.$on("$destroy", function(){
		$store.off();
	});
	
	$scope.setHeight = function(){
		return $heighter.setHeight(Constant.DONATE_VIEW);
	}

	$donateView.initViewParams();

	$scope.init();

	$donateLang.setLang($scope);
}]);

controllers.controller("mainCtrl", ["$scope", "$routeParams", "$rootScope", "$manager", "$auth", "$action",
									 "$mainView", "$dialogView", "$navView", "$mainLang", "$demon", "$way",
									  "$adView", "$heighter", "$udatar",
						function($scope, $routeParams, $rootScope, $manager, $auth, $action, $mainView,
								 $dialogView, $navView, $mainLang, $demon, $way, $adView, $heighter, $udatar){
	$rootScope.locationTitle = $manager.instance.getUser().getNick();
	$way.step($scope, "/main");
	$way.playBack();

	$navView.setNavBut(Constant.MAIN_VIEW);

	$scope.response = function(response){
		$mainView.manageView($scope, response);
	}

	//user actions
	$scope.update = function(){
		$auth.update($scope);
	}
	
	$scope.bidLikes = function(answer){
		$dialogView.showDialogBidLikes(answer.getId());
	}

	$scope.addNewPosts = function(){
		$mainView.newPostsLoad(true);
		$action.moreFields($scope);
	}

    $scope.setHeight = function(){
		return $heighter.setHeight(Constant.MAIN_VIEW);
	}

	$mainView.setGuidePost();
	
	$demon.startNewsDemon();

	$mainView.initViewParams();
	
	if($manager.instance.getUser().isFirstTime()){
		$manager.instance.getDataManager().setSetting(Constant.FIRSTTIME_SETTING, 0, function(){
			$mainView.setGuideFirst();
			$way.stopBack();
		});
	}

	//initial state
	$mainView.setInfo($scope, $manager.instance.getUser());
	$mainView.initSwipe();
	$adView.init();

	$scope.$on("$destroy", function(){
		$mainView.removeScrollListener();
	});

	$mainLang.setLang($scope);
}]);

controllers.controller("tasksCtrl", ["$scope", "$routeParams", "$rootScope", "$action", "$tasksView", "$navView", "$tasksLang", "$dialogView", "$way", "$heighter",
						function($scope, $routeParams, $rootScope, $action, $tasksView, $navView, $tasksLang, $dialogView, $way, $heighter){
	$rootScope.locationTitle = $dialogView.strings.tasksTitle;
	$way.step($scope, "/tasks");

	$navView.setNavBut(Constant.TASKS_VIEW);

	$scope.response = function(response){
		$dialogView.hideLoading();
		$tasksView.manageView($scope, response);
	}

	//check task
	$scope.refreshTask = function(task){
		$action.refreshTask($scope, task);
	}

	//delete task
	$scope.deleteTask = function(task){
		$dialogView.showDeleteTask($scope, task);
	}
	
	$scope.tasks = function(){
		$dialogView.showLoading();
		$action.tasks($scope);
	}

	$scope.setHeight = function(){
		return $heighter.setHeight(Constant.TASKS_VIEW);
	}

	$tasksView.initViewParams();

	//initial state
	$tasksView.initSwipe(); // order is
	$scope.tasks();			// important
	
	$scope.$on("$destroy", function(){
		$tasksView.initSwipeOk = false;
		$tasksView.removeScrollListener();
    });

    $tasksLang.setLang($scope);
}]);

controllers.controller("earnCtrl", ["$scope", "$rootScope", "$action", "$location", "$earnView", "$earnLang", "$manager", "$dialogView", "$way",
						function($scope, $rootScope, $action, $location, $earnView, $earnLang, $manager, $dialogView, $way){
	$rootScope.locationTitle = $dialogView.strings.earnTitle;
	$way.step($scope, "/earn");

	var isRunnable = $manager.instance.getBot().isRunnable();

	// set values in depending on the bot
	if(!isRunnable){
		$rootScope.earnedDeposit = $manager.instance.getBot().getEarned();
		$rootScope.stateDeposit = $manager.instance.getUser().getCash().getDeposit();
	}else
		$rootScope.stateDeposit = $manager.instance.getUser().getCash().getDeposit() - $manager.instance.getBot().getEarned();
	
	$scope.response = function(response){
		$earnView.manageView($scope, response);
	}

	$scope.back = function(){
		$way.goBack($scope);
	}

	$scope.playPause = function(){
		if(isRunnable){
			isRunnable = false;
			$action.stop($scope);
		}else{
			isRunnable = true;
			$action.run($scope);
		}
	}
	
	$earnView.setSpeed($scope);
	$earnView.initViewParams();

	$earnView.setRunState(isRunnable);
	$earnView.setManAndDrill();	//set mainer on the rock

	$earnLang.setLang($scope);
}]);

controllers.controller("bidLikeCtrl", ["$scope", "$routeParams", "$rootScope", "$manager", "$action", "$correct", "$bidLikeView", "$navView", "$dialogView", "$bidLang", "$way", "$heighter",
						function($scope, $routeParams, $rootScope, $manager, $action, $correct, $bidLikeView, $navView, $dialogView, $bidLang, $way, $heighter){
	$rootScope.locationTitle = $dialogView.strings.bidLikesTitle;
	$way.step($scope, "/bid_like");

	$navView.setNavBut(Constant.BID_VIEW);

	$scope.type = Constant.LIKE_TYPE;
	$scope.targetCount = Constant.LIKE_MIN_BID;
	$scope.price = "";

	$scope.response = function(response){
		$bidLikeView.manageView($scope, response);
	}
	
	$scope.bid = function(){
		var status = $correct.checkCorrect($scope.type, $scope.link, $scope.targetCount);
		$bidLikeView.setButAnim(true);

		if(status.status == Constant.OK_STATUS){
			$action.bid($scope, new Bid($scope.link, $scope.targetCount, $scope.type));
		}else{
			$bidLikeView.setButAnim(false);
			$dialogView.showToast(status.message);
		}
	}
	
	$scope.changePrice = function(){
		if($scope.targetCount >= 0 && $scope.targetCount != '')
			$bidLikeView.setPrice($scope, $scope.targetCount * Constant.LIKE_PRICE, 1);
		else
			$bidLikeView.setPrice($scope, $scope.targetCount * Constant.LIKE_PRICE, 2);
	}

	//переключатель на странице лайков
	$scope.switcherLikes = function(num){
		$bidLikeView.switcherLikes($scope, num);
	}

	$scope.bidLikes = function(post){
		$dialogView.showDialogBidLikes(post.getId());
	}

	$scope.addNewPosts = function(){
		$bidLikeView.newPostsLoad(true);
		$action.moreFields($scope);
	}

	$scope.setHeight = function(){
		return $heighter.setHeight(Constant.BID_VIEW);
	}

	$bidLikeView.initViewParams();
	
	$bidLikeView.setPosts($scope);
	$bidLikeView.checkNewPosts();

	$bidLang.setLang($scope);
}]);

controllers.controller("bidSubsCtrl", ["$scope", "$rootScope", "$manager", "$action", "$correct", "$bidSubsView", "$navView", "$dialogView", "$bidLang", "$manager", "$way", "$heighter",
						function($scope, $rootScope, $manager, $action, $correct, $bidSubsView, $navView, $dialogView, $bidLang, $manager, $way, $heighter){
	$rootScope.locationTitle = $dialogView.strings.bidSubsTitle;
	$way.step($scope, "/bid_subs");

	$navView.setNavBut(Constant.BID_VIEW);

	var numPanel = 1;				// what content is visible now(1 - bid on acc, 2 - bid by link)
	$scope.type = Constant.SUBSCRIBE_TYPE;
	$scope.link = $manager.instance.getUser().getNick();
	$scope.targetCountAcc = Constant.SUBSCRIBE_MIN_BID;
	$scope.targetCountLink = Constant.SUBSCRIBE_MIN_BID;
	$scope.priceAcc = "";
	$scope.priceLink = "";

	$scope.response = function(response){
		$bidSubsView.manageView($scope, response);
	}
	
	$scope.bid = function(){
		var status = null;

		var link = Constant.HOME_PAGE + "/" + $scope.link;
		if(numPanel == 1){
			status = $correct.checkCorrect($scope.type, link, $scope.targetCountAcc);
		}else{
			status = $correct.checkCorrect($scope.type, link, $scope.targetCountLink);
		}

		$bidSubsView.setButAnim(numPanel, true);

		if(status.status == Constant.OK_STATUS){
			if(numPanel == 1){
				$action.bid($scope, new Bid(link, $scope.targetCountAcc, $scope.type));
			}else{
				$action.bid($scope, new Bid(link, $scope.targetCountLink, $scope.type));
			}
		}else{
			$bidSubsView.setButAnim();
			$dialogView.showToast(status.message);
		}
	}
	
	$scope.changePrice = function(){
		if(numPanel == 1){
			if($scope.targetCountAcc >= 0 && $scope.targetCountAcc != '')
				$bidSubsView.setPrice($scope, $scope.targetCountAcc * Constant.SUBSCRIBE_PRICE, 1);
			else
				$bidSubsView.setPrice($scope, $scope.targetCountAcc * Constant.SUBSCRIBE_PRICE, 3);
		}else{
			if($scope.targetCountLink >= 0 && $scope.targetCountLink != '')
				$bidSubsView.setPrice($scope, $scope.targetCountLink * Constant.SUBSCRIBE_PRICE, 2);
			else
				$bidSubsView.setPrice($scope, $scope.targetCountLink * Constant.SUBSCRIBE_PRICE, 3);
		}
	}

	$scope.acceptSubscribe = function(){
		$bidSubsView.acceptSubscribe();
	}

	//переключатель на странице подписчиков
	$scope.switcherSubs = function(num){
		numPanel = num;
		$bidSubsView.switcherSubs(num);
		if(num == 1){
			$scope.link = $manager.instance.getUser().getNick();
		}
	}
	
	$scope.setHeight = function(){
		return $heighter.setHeight(Constant.BID_VIEW);
	}

	$bidSubsView.initViewParams();
	
	$bidLang.setLang($scope);
}]);


controllers.controller("navCtrl", ["$scope", "$adView", 
						function($scope, $adView){
	
	$scope.showAd = function(){
		$adView.showAd();
	}

}]);


controllers.controller("settingsCtrl", ["$scope", "$window", "$auth", "$settingsView", "$settingsLang", "$dialogView", "$navView", "$way", "$action",
						function($scope, $window, $auth, $settingsView, $settingsLang, $dialogView, $navView, $way, $action){
	$way.step($scope, "/settings");

	$scope.response = function(response){
		$settingsView.manageView($scope, response);
		setTimeout(function(){
			$dialogView.hideLoading();
		}, 500);
	}
	
	$scope.logout = function(){
		$navView.originButState();
		$dialogView.showLoading();
		$auth.logout($scope);
	}

	$scope.back = function(){
		$way.goBack($scope);
	}

	$scope.openService = function(service){
		$settingsView.openService(service, $window);
	}

	$scope.watchGuide = function(){
		$settingsView.watchGuide();
	}

	$scope.showPrivacy = function(){
		$settingsView.showPrivacy($window);
	}

	$scope.setLinkOnApp = function(appId){
		$settingsView.setLinkOnApp(appId);
	}

	$scope.setImageOnApp = function(num){
		$settingsView.setImageOnApp(num);
	}

	$settingsView.initViewParams();

	$action.version($scope);
	$action.apps($scope);

	$settingsLang.setLang($scope);
}]);


controllers.controller("authtroubleCtrl", ["$scope", "$window", "$authTroubleView", "$authTroubleLang", "$way",
						function($scope, $window, $authTroubleView, $authTroubleLang, $way){
	$way.step($scope, "/authtrouble");
	
	$scope.back = function(){
		$way.goBack($scope);
	}

	$scope.feedBackUs = function(){
		$authTroubleView.feedBackUs($window);
	}

	$authTroubleView.initViewParams();

	$authTroubleLang.setLang($scope);
}]);


controllers.controller("topCtrl", ["$scope", "$topView", "$topLang", "$action", "$dialogView", "$way",
						function($scope, $topView, $topLang, $action, $dialogView, $way){
	$topView.clearTimer();
	$way.step($scope, "/top");

	$scope.response = function(response){
		$topView.manageView($scope, response);
		setTimeout(function(){
			$dialogView.hideLoading();
		}, 500);
	}
	
	$scope.back = function(){
		$way.goBack($scope);
	}
	
	$scope.showHelpDialog = function(){
		$topView.showHelpDialog();
	}
	
	$scope.hideHelpDialog = function(){
		$topView.hideHelpDialog();
	}

	$topView.initViewParams();

	$dialogView.showLoading();
	$action.top($scope);
	
	$topLang.setLang($scope);
}]);


controllers.controller("lvlPrizeCtrl", ["$scope", "$lvlPrizeView", "$lvlPrizeLang", "$way",
						function($scope, $lvlPrizeView, $lvlPrizeLang, $way){
	
	$way.step($scope, "/lvlprize");

	$scope.back = function(){
		$way.goBack($scope);
	}

	$lvlPrizeView.initViewParams();
	
	$lvlPrizeLang.setLang($scope);
	$lvlPrizeView.setItems($scope);
}]);


controllers.controller("guideCtrl", ["$scope", "$guideView", "$guideLang",
						function($scope, $guideView, $guideLang){
	$guideView.setActionClick();

	$guideLang.setLang($scope);
}]);


controllers.controller("mineAdCtrl", ["$scope", "$window", "$mineAdView", "$mineAdLang",
						function($scope, $window, $mineAdView, $mineAdLang){

	$scope.handleAd = function(num){
		$mineAdView.handleAd($window, num);
	}
	
	$mineAdLang.setLang($scope);
}]);

controllers.controller("privacyCtrl", ["$scope", "$privacyView", "$privacyLang", "$way",
						function($scope, $privacyView, $privacyLang, $way){
	$way.step($scope, "/privacy");
	
	$scope.back = function(){
		$way.goBack($scope);
	}

	$privacyView.initViewParams();

	$privacyLang.setLang($scope);
}]);

